package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````H9H``#0````4PP```@0`!30`(``)
M`"@`'``;``$``'#0O0``T#T!`-`]`0`(````"`````0````$````!@```#0`
M```T@```-(```"`!```@`0``!0````0````#````5`$``%2!``!4@0``&0``
M`!D````$`````0````$``````````(````"```#<O0``W+T```4`````@```
M`0```/2^``#TO@$`]+X!`$0"``!X$@``!@````"````"`````+\```"_`0``
MOP$```$````!```&````!`````0```!P`0``<($``'"!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D]+X`
M`/2^`0#TO@$`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50"0+RKL;R-::S<AX_WPI\;EQ(Y7UV$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`4,)`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=R0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%<```!9````````````````````
M`````%H```!>`````````&``````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]
M]MOW`%X&I(?_`:\TZ+%(G>?.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`"
M;7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)B
MV^VYC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MOO-!+?79OXW"90NZA:@E#UI\BQZ@A
M8F0'?JF<FV+0^H+L+/:+:W^:?(;PEGS1GRS\[PM1^9!U@@U#9DL0!6RRS3RM
M.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;>J\J?R=6R
M<0`````````````````````1```````````````@````+0``````````````
M(````#P``````````````"````!0```````````````@````C`,``(B5````
M````$@```$\"``"LE@```````!(```#F`@``?)4````````2````R@(``!B7
M````````$@```'\$```HP0$``````"``%P#D`0``X)<````````2````PP(`
M``28````````$@```-0!``#TE0```````!(````+!0``A=T``#`````2``T`
MZ`,``#C!`0``````$``8`'T"``",F````````!(```"H`@``3)8````````2
M````OP0``#3!`0`$````$0`7`"D#``"`F````````!(````G!0``:=H``-("
M```2``T`9`0``,7/``"L````$@`-`),#``#TE@```````!(```".`@``O)@`
M```````2````.@,``*R5````````$@```/<#``!LT0$``````!``&``/`0``
M5)<````````2````0@0``)25````````$@```'`$``#AT@``B`<``!(`#0"9
M!```F<T``)`````2``T`5P0``*W/```6````$@`-`+4"``!8E@```````!(`
M``!X`@``))<````````2````K0$``)B7````````$@```!8#``"PF```````
M`!(```"F`P``.,$!``0````A`!@`-P(``-R6````````$@```#X"``!@EP``
M`````!(```#8`@``,)<````````2````U0,``#C!`0``````$``7`/,"``#L
MEP```````!(```">````0)@````````2````O0(``)B8````````$@```%X#
M``!(EP```````!(````Q`@``I)@````````2````5P(``*"5````````$@``
M`*<#```XP0$`!````"$`&``"!```;-$!```````0`!@`,P,``%#!`0`$````
M$0`8``\$```)W@```@```!(`#0"X`0``9)8````````2````A@$```"7````
M````$@```*\$``#)W0``0````!(`#0#K!```0=(``*`````2``T`&00```S>
M````````$@`.`)<"```PE@```````!(```"#!```H9H````````2``T`V`0`
M`%R5````````$@`+`+X```!XEP```````!(````(`P``))8````````2````
M`@$``$S!`0`!````$0`8`-$"```HF````````!(```"*!```%-X```0````1
M``\`W`,``#C!`0``````$``8`&4#``!,F````````!(```!]`P``N)4`````
M```2````:@```,B7````````$@```!P!``#XEP```````!(```#6!```)<T`
M`#`````2``T`3P$``!B6````````$@````H$``!LT0$``````!``&`#>!```
M+<X``(`!```2``T`TP```-"5````````$@```&8"``!`E@```````!(```"'
M````=)@````````2````'0(``,B8````````$@```,8!```TF````````!(`
M``#A````E)8````````2````\P```%B8````````$@```"T!``!(P0$`!```
M`!$`&`"E`P``.,$!``0````1`!@`>`$``'"6````````$@```-\"``"PEP``
M`````!(```#V`P``;-$!```````0`!@`_00``/G1```V````$@`-`*\````,
ME@```````!(````A`P``T)8````````2````.`$``!R8````````$@```'T$
M```HP0$``````!``%P!O`P``;)<````````2````PP,``$#!`0`$````$0`8
M`#`$```QT@``$````!(`#0`"`@``H)8````````2````[P$``,26````````
M$@```*`#``#9F```R`$``!(`#0!4`0``Q)4````````2````2@,``.B5````
M````$@```$$#``!\E@```````!(````!`P``W)4````````2````[0(```"6
M````````$@```(4"``"(EP```````!(```#[`0``Z)8````````2````A0,`
M`!"8````````$@```,D$``!QT```B`$``!(`#0!1`P``B)8````````2````
M60$``-27````````$@```*\"``"DEP```````!(```!+!```/=T``$@````2
M``T`>````#R7````````$@```)8!``!DF````````!(````?!```*<X```0`
M```2``T`GP$``+B6````````$@```&4!``"\EP```````!(`````;&EB<&5R
M;"YS;RXU+C$X`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)P=&AR96%D+G-O+C``<'1H<F5A
M9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L
M<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`
M<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K
M`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M
M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V
M-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`
M<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S
M`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M
M87)M:&8N<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A
M<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L
M:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N
M86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?
M<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U
M<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`````````
M```````"``,``@`"``$````"`````0`!``(``@`!``(``0`!``(``@`"``$`
M```"``$``0`!``(``@````(``@`#``,``@`!``(````"``(``P`#``(``0`"
M``$```````$``0`!``(``0`!`````@````(``0`!``(``@```````0````$`
M`0````(````#`````````````@````(``0`!`````@````$``@`$``$`````
M``$``@`"``(``@`"``(``@`"``$``@````(``0```````0```````0`!`*\#
M```0````(````!1I:0T```0`/04````````!``$`#0(``!`````@````%&EI
M#0```P`]!0````````$``0!<`@``$``````````4:6D-```"`#T%````````
M),$!`!4"```XP0$`%$\``$#!`0`460``2,$!`!1.``!,P0$`%#L``%#!`0`4
M+P``#,`!`!8'```0P`$`%@4``!3``0`6&@``&,`!`!8L```<P`$`%A<``"#`
M`0`60```),`!`!9>```HP`$`%D<``"S``0`680``,,`!`!9?```TP`$`%@P`
M`#C``0`68@``/,`!`!94``!`P`$`%D0``$3``0`6.@``2,`!`!8V``!,P`$`
M%D@``%#``0`6$```5,`!`!8>``!8P`$`%C$``%S``0`64```8,`!`!9@``!D
MP`$`%F<``&C``0`63```;,`!`!9;``!PP`$`%@8``'3``0`6;@``>,`!`!9<
M``!\P`$`%E4``(#``0`6(P``A,`!`!9D``"(P`$`%A4``(S``0`6,@``D,`!
M`!8"``"4P`$`%@@``)C``0`6'P``G,`!`!8E``"@P`$`%FL``*3``0`6*@``
MJ,`!`!89``"LP`$`%B0``+#``0`66```M,`!`!8Y``"XP`$`%F,``+S``0`6
M(```P,`!`!9I``#$P`$`%E$``,C``0`6;P``S,`!`!9!``#0P`$`%F@``-3`
M`0`6"@``V,`!`!8G``#<P`$`%D(``.#``0`6"P``Y,`!`!9E``#HP`$`%E8`
M`.S``0`6/```\,`!`!9+``#TP`$`%B@``/C``0`6/P``_,`!`!9-````P0$`
M%FP```3!`0`620``",$!`!82```,P0$`%@\``!#!`0`6*0``%,$!`!8K```8
MP0$`%B$``!S!`0`6%@``(,$!`!9*```(0"WI6@$`ZPB`O>@$X"WE!."?Y0[@
MC^`(\+[EB"H!``#&C^(2RHSBB/J\Y0#&C^(2RHSB@/J\Y0#&C^(2RHSB>/J\
MY0#&C^(2RHSB</J\Y0#&C^(2RHSB:/J\Y0#&C^(2RHSB8/J\Y0#&C^(2RHSB
M6/J\Y0#&C^(2RHSB4/J\Y0#&C^(2RHSB2/J\Y0#&C^(2RHSB0/J\Y0#&C^(2
MRHSB./J\Y0#&C^(2RHSB,/J\Y0#&C^(2RHSB*/J\Y0#&C^(2RHSB(/J\Y0#&
MC^(2RHSB&/J\Y0#&C^(2RHSB$/J\Y7A'P$8`QH_B$LJ,X@3ZO.4`QH_B$LJ,
MXOSYO.4`QH_B$LJ,XO3YO.4`QH_B$LJ,XNSYO.4`QH_B$LJ,XN3YO.4`QH_B
M$LJ,XMSYO.4`QH_B$LJ,XM3YO.4`QH_B$LJ,XLSYO.4`QH_B$LJ,XL3YO.4`
MQH_B$LJ,XKSYO.4`QH_B$LJ,XK3YO.4`QH_B$LJ,XJSYO.4`QH_B$LJ,XJ3Y
MO.4`QH_B$LJ,XISYO.4`QH_B$LJ,XI3YO.4`QH_B$LJ,XHSYO.4`QH_B$LJ,
MXH3YO.4`QH_B$LJ,XGSYO.4`QH_B$LJ,XG3YO.4`QH_B$LJ,XFSYO.4`QH_B
M$LJ,XF3YO.4`QH_B$LJ,XESYO.4`QH_B$LJ,XE3YO.4`QH_B$LJ,XDSYO.4`
MQH_B$LJ,XD3YO.4`QH_B$LJ,XCSYO.4`QH_B$LJ,XC3YO.5X1\!&`,:/XA+*
MC.(H^;SE>$?`1@#&C^(2RHSB'/F\Y0#&C^(2RHSB%/F\Y0#&C^(2RHSB#/F\
MY0#&C^(2RHSB!/F\Y0#&C^(2RHSB_/B\Y0#&C^(2RHSB]/B\Y0#&C^(2RHSB
M[/B\Y0#&C^(2RHSBY/B\Y0#&C^(2RHSBW/B\Y0#&C^(2RHSBU/B\Y0#&C^(2
MRHSBS/B\Y0#&C^(2RHSBQ/B\Y0#&C^(2RHSBO/B\Y0#&C^(2RHSBM/B\Y0#&
MC^(2RHSBK/B\Y0#&C^(2RHSBI/B\Y0#&C^(2RHSBG/B\Y0#&C^(2RHSBE/B\
MY7A'P$8`QH_B$LJ,XHCXO.4`QH_B$LJ,XH#XO.4`QH_B$LJ,XGCXO.4`QH_B
M$LJ,XG#XO.4`QH_B$LJ,XFCXO.4`QH_B$LJ,XF#XO.4`QH_B$LJ,XECXO.4`
MQH_B$LJ,XE#XO.4`````+>GP08BP!9`%J`21!*D#D@.J__<H[TGRO''`\@`!
M2?9``,#R```*1@3P6OI,\DP3P/(!`QUX`"T`\(R`3/)(%,#R`00@:/_WU.^0
M^!HD`T8@:$+P`@*#^!HD__?*[P6;G^U5:Y_M5GL%,P3ND#JX[F1;->X&:[3N
MQVOQ[A#ZD/@:)$+P`0*`^!HD`/.0@)@`3?)0*/_WJNX$F4SR,!/`\@$#!9K`
M\@$(#&A=:`$JR+\.'T[RK!/(OP;K@@;`\@`#!T9.\J@0/&#`\@``O6#(OP?Q
M#`1X8$_P!`#[8$CX\'Q(^/0,!=U1^`1?L4)$^`1?^=$"\8!%`"0#-0"46/CH
M#`,R1_@E0#M&3/954<#R``'_]_KN3?)0)<#R`04$1G"S6/CH#$WR4"7_]S#N
M3?98<`>IP/(``,#R`04"\#W_(+-8^.@,__?\[?_WTNX@1@BPO>CP@?_W..Y-
M\E`CP/(!`T/XZ`PHLTSR2!3`\@$$__?B[2!H__<\[X#X;59BYU7XZ`S_]P3O
M!$;*YU7X[`P0L03P:/G4YP>I3?;T8,#R```"\`K_1?CL#``HR=#PY__WRNX!
M(/_W2NX`````````````@/___\]!3_``"T_P``X"O&I&!+0!M-_X$,!-^`3-
M`T@$2__W&N[_]^KN"=X``-F8``#)W0``%#"?Y10@G^4#,(_@`B"3YP``4N,>
M_R\!!___ZB`E`0`D`0``!TM,\C@0P/(!`!L:!BL`V'!'0/(``\#R``,`*_C0
M&$<[P0$`3/(X$TSR.!#`\@$#P/(!`!L:FQ`#Z]-S61``T7!'0/(``L#R``(`
M*OC0$$<0M4SR5!3`\@$$(W@;N?_WS_\!(R-P$+U+]OQ@P/(!``BU`V@KL4#R
M``/`\@`#`[&81[WH"$#-YP`````MZ?!/K?4_?0=&`/%X#C@W(*X;D,WI$*L[
M:``@>F@(-PN0=T5/ZA-H3^H#)4CJ`B@4E<WX5(!/ZA)IW>D414_J`B%/ZA,J
M%I%/Z@-C!/1_!$_P``7-^%R01.H#`"E&S>D2`4_J`FS=Z18!3_```0U&2NH"
M:@#T?P!/ZA(K0.H,!,WI#D5/\``%#97=Z1)%"O1_0D_P``/-^"BP1.H"!$7J
M`P4(\/\"3_```T3J`@1%Z@,%W>D*(T_P``/=Z0X!`O1_0LWX,)!`Z@(`0>H#
M`=WI#"-/\``#1ND"14/J`0,"\/\"0NH``N;H!".5T0WQV`XLKQRN#?'P#`WQ
M@`A/\$`)_ND"`??I`B/XZ0)%0D!+0/;I`@%B0&M`0D!+0)`8N?$!"4_JTGI*
MZD,*3_```TKJ``+LZ0(CX]$;GPWU/GX;F=?I`&?1Z0@!S>D(9]WX(*#=^"2P
MS>D``4_JVFA51DCJ2QC=^&RP&YEJ`7[IH&=(Z@((V^D"J]'I!@$/]I1CT^D`
M(\WI!JO=^&RPS>D"`=WI``';Z02K-AC=Z09%3T&V&,WI!*M?0=WI`JL6ZP@&
MW>D&(T?Q``?=Z00!*NH$!-WX&,`KZ@4%$$`90`:;($,'G!;K``A!Z@4!3^J,
M<D_JDPI'ZP$)2NJ$>MWI"`%"Z@H"3_``"\WI$(F21LWI"JL"Z@`*"^H!"\WI
M#JO=Z02KW>D0B4_P``DJZ@`"*^H!`][I`JO=Z0(!3^K89D_J2!1&ZDD6$.L*
M`$;J!`9!ZPL!W>D.JTKJ`@I+Z@,+#_;$4]/I`".`&%E!S>D,`=WI#$4`(0B;
M%.L*!-WX(,!%ZPL%%.L&"D7Q``O-Z0ZKW?@DL)@(3^J,<D#JBW#=Z0ZK`D-/
M\``+3^K;9Q!&W>D0(\WI#`%/ZMIF`D`+0-[I!`%&ZDL6S>D2(T_J2A3=Z00C
M@!A900_V3%/3Z0`C$AA+0=WI"@'-Z1`CW>D2(R#J"``AZ@D!`D-&Z@0`W>D0
M10M#1^H&`<WI%`%/ZI@`W?A0P*080.J)<$_JB')=00)#%.L,!D7Q``?>Z09%
M$$8/]O1#T^D`(P`AS>D0`1(9L$9K0=WI#D7-Z10C3_``"01`#4#=Z0H!3^I(
M$LWI#D7=Z11%S>D29T_JV&8`&4;J219I0<WI"@'=Z0P!%D/=Z0Y%3^J*<B#J
M"@`AZ@L!($,I0]WI"D4`)R083^J:`$U!I!E`ZHMP1?$`!:)&S>D.10)#WND(
M10_V<$'1Z0`!3_``"Q9&S>D*9P`93^K:9FE!W>D21<WI%`%/ZDH2W>D*`4;J
M2Q860T_JB'($0`U`S>D210`GW>D4`=WI#$4D&$U!W>D0`<WI#$7=Z1)%(.H(
M`"'J"0$@0RE#W>D,12083^J8`$U!I!E`ZHEP1?$`!:!&S>D210)#WND*10_V
M[#'1Z0`!3_``"19&S>D,9P`93^K89FE!W>D.1<WI%`%/ZD@2W>D,`4;J2186
M0T_JBG($0`U`W>D4`0`GS>D.1=WI$$4D&$U!W>D*`<WI$$7=Z0Y%(.H*`"'J
M"P$@0RE#W>D012083^J:`$U!I!E`ZHMP1?$`!:)&S>D.10)#WND,10_V:#'1
MZ0`!3_``"Q9&S>D09P`93^K:9FE!W>D21<WI%`%/ZDH2W>D0`4;J2Q860T_J
MB'($0`U`W>D4`0`GS>D21=WI"D4D&$U!W>D,`<WI"D7=Z1)%(.H(`"'J"0$@
M0RE#W>D*12083^J8`$U!I!E`ZHEP1?$`!:!&S>D210)#WND.10_VY"'1Z0`!
M3_``"19&S>D*9P`93^K89FE!W>D.1<WI%`%/ZD@2W>D*`4;J21860T_JBG($
M0`U`W>D4`0`GS>D.1=WI#$4D&$U!W>D0`<WI#$7=Z0Y%(.H*`"'J"P$@0RE#
MW>D,12083^J:`$U!I!E`ZHMP1?$`!:)&S>D.10)#WND010_V8"'1Z0`!3_``
M"Q9&S>D,9P`93^K:9FE!W>D21<WI%`%/ZDH2W>D,`4;J2Q860T_JB'($0`U`
MW>D4`0`GS>D21=WI$$4D&$U!W>D*`<WI$$7=Z1)%(.H(`"'J"0$@0RE#W>D0
M12083^J8`$U!I!E`ZHEP1?$`!:!&S>D210)#WND210_VW!'1Z0`!3_``"19&
MS>D09P`93^K89FE!W>D.1<WI%`%/ZD@2W>D0`4;J21860T_JBG($0`U`W>D4
M`0`GS>D.1=WI"D4D&$U!W>D,`<WI"D7=Z0Y%(.H*`"'J"P$@0RE#W>D*1208
M3^J:`$U!I!E`ZHMP1?$`!:)&S>D.10)#WND410_V6!'1Z0`!3_``"Q9&S>D*
M9P`93^K:9FE!W>D21<WI%`%/ZDH2W>D*`4;J2Q860T_JB'($0`U`W>D4`0`G
MS>D21=WI#$4D&$U!W>D0`<WI#$7=Z1)%(.H(`"'J"0$@0RE#W>D,12083^J8
M`$U!I!E`ZHEP1?$`!:!&S>D210)#WND610_VU`'1Z0`!3_``"19&S>D,9P`9
M3^K89FE!W>D.1<WI%`%/ZD@2W>D,`4;J21860T_JBG($0`U`W>D4`0`GS>D.
M1=WI$$4D&$U!W>D*`<WI$$7=Z0Y%(.H*`"'J"P$@0RE#W>D012083^J:`$U!
MI!E`ZHMP1?$`!:)&S>D.10)#WND810_V4`'1Z0`!3_``"Q9&S>D09P`93^K:
M9FE!W>D21<WI%`%/ZDH2W>D0`4;J2Q860T_JB'($0`U`W>D4`0`GS>D21=WI
M"D4D&$U!S>D*1=WI#`'=Z1)%(.H(`"'J"0$@0RE#W>D*12083^J8`$U!I!E`
MZHEP1?$`!:!&S>D210)#WND:10_RS''1Z0`!3_``"19&S>D*9P`93^K89FE!
MW>D.1<WI%`%/ZD@2W>D*`4;J21860T_JBG($0`U`W>D4`0`GS>D.1=WI#$4D
M&$U!W>D0`<WI#$7=Z0Y%(.H*`"'J"P$@0RE#W>D,12083^J:`$U!I!E`ZHMP
M1?$`!:)&S>D.10)#WND<10_R2''1Z0`!3_``"Q9&S>D,9P`93^K:9FE!W>D2
M1<WI%`%/ZDH2W>D,`4;J2Q860T_JB'($0`U`W>D4`0`GS>D21=WI$$4D&$U!
MW>D*`<WI$$7=Z1)%(.H(`"'J"0$@0RE#W>D012083^J8`$U!I!E`ZHEP1?$`
M!:!&S>D210)#WND>10_RQ&'1Z0`!3_``"19&S>D09P`93^K89FE!W>D.1<WI
M%`%/ZD@2W>D0`4;J21860T_JBG($0`U`S>D.10`GW>D4`=WI"D4D&$U!W>D,
M`<WI"D7=Z0Y%(.H*`"'J"P$@0RE#W>D*12083^J:`$U!I!E`ZHMP1?$`!:)&
MS>D.10)#WND@10_R0&'1Z0`!3_``"Q9&S>D*9P`93^K:9FE!W>D21<WI%`%/
MZDH2W>D*`4;J2Q860T_JB'($0`U`W>D4`0`GS>D21=WI#$4D&$U!W>D0`<WI
M#$7=Z1)%(.H(`"'J"0$@0RE#W>D,12083^J8`$U!I!E`ZHEP1?$`!:!&S>D2
M10)#WNDB10_RO%'1Z0`!3_``"19&S>D,9P`93^K89FE!W>D.1<WI%`%/ZD@2
MW>D,`4;J21860T_JBG($0`U`W>D4`0`GS>D.1=WI$$4D&$U!W>D*`<WI$$7=
MZ0Y%(.H*`"'J"P$@0RE#W>D012083^J:`$U!I!E`ZHMP1?$`!:)&S>D.10)#
MWNDD10_R.%'1Z0`!3_``"Q9&S>D09P`93^K:9FE!W>D21<WI%`%/ZDH2W>D0
M`4;J2Q860T_JB'($0`U`W>D4`<WI$D7=Z0I%)!A-0=WI#`'-Z0I%W>D212#J
M"``AZ@D!($,I0]WI"D4D&$U!S>D*1=WI"@%/ZI@$1.J)=$_JF06`&47J!`=$
MZ@(&WNDF(P_RK$75Z0!%0?$``<WI&&=/ZM!H$AG-Z1(!:T'-Z0HCW>D8(P`C
MW>D.10`A1@%(ZD$8S>D<(Q1`'4#=Z0PCS>D.14CJ!@C=Z0I%$AEK0=WI$$7-
MZ0HCW>D.(R3J"@0EZ@L%(D,K0]WI"D42&4_JBG1K01+K"`9#\0`'S>D.9T_J
MF@9/ZIL'1NJ+=M[I*(E&Z@0*1^H&"\WI"JO=Z1A%W>D*9]WI#B,`(V9`;T`/
M\@A%U>D`14_JTFH4ZP@$2NI#&D7K"07=Z1*)B.H&"(GJ!PG-Z12)3^I"&-WI
M$&=(Z@H(W?A0P*09?4$4ZPP&1?$`!\WI#&?=Z0Q%A@A&ZH%VCP@4ZP@$1^H&
M"T7Q``7-Z1)%A`?>Z2H!1NH$"LWI#*O=Z0IGW>D,1=WI$HE/\``)=$!]0.&G
MU^D`9T_JV&J`&4KJ21IY0=WI#F=F0&]`W>D<1<WI%&=/ZD@6W?A0P``9:4%&
MZ@H&$.L,!$'Q``7-Z1!%W>D0`90(1.J#=)T(@!E%Z@0+0?$``<WI#@&0!][I
M+"-$Z@`*S>D0J]WI#$7=Z1`!W>D.9P`G8$!I0,.EU>D`14_JUFH2&4KJ1QIK
M0=WI$D5$0$U`S>D4170!"IU$Z@H$W?A0P%(90_$``Q+K#`!#\0`!S>D*`=WI
M"@%/ZHAR`!G>Z2Y%0?$``<WI$@%/ZI@`3^J9`4#JB7#=Z1*K0.H""$'J``G-
MZ0J)3_``"]WI$"-/ZMIHW>D*`4CJ2QA00%E`H:/3Z0`C$AEK0=WI#D5$0$U`
MS>D414_J2A0,G43J"`3=^%#`4AE#\0`#$NL,`$/Q``'-Z0P!W>D,`;('`!G>
MZ3!%0?$``<WI#@&P"+D(0.J'<-WI#HE`Z@(&0>H`!\WI#&=/\``)W>D*(T_J
MV&;=Z0P!1NI)%E!`64"#H]/I`",2&6M!W>D2141`34#-Z11%3^I(%!"=-$/=
M^%#`4AE#\0`#$NL,`$/Q``'-Z1`!W>D0`4_JBG(`&=[I,D5!\0`!S>D2`4_J
MF@!/ZIL!0.J+<-WI$F=`Z@(*0>H`"\WI$*L`)]WI#"-/ZM9JW>D0`4KJ1QI0
M0%E`9*/3Z0`C$AEK0=WI#D5$0$U`S>D4170!"IU$Z@H$W?A0P%(90_$``Q+K
M#`!#\0`!S>D*`=WI"@%/ZHAR`!G>Z31%0?$``<WI#@%/ZI@`3^J9`4#JB7#=
MZ0ZK0.H""$'J``G-Z0J)3_``"]WI$"-/ZMIHW>D*`4CJ2QA00%E`1*/3Z0`C
M$AEK0=WI$D5$0$U`S>D414_J2A0,G43J"`3=^%#`4AE#\0`#$NL,`$/Q``'-
MZ0P!W>D,`;('`!G>Z39%0?$``<WI$@&P"+D(0.J'<-WI$HE`Z@(&0>H`!\WI
M#&=/\``)W>D*(T_JV&;=Z0P!1NI)%E!`64`FH]/I`",2&6M!W>D.141`34#-
MZ11%3^I(%!"=-$/=^%#`4AE#\0`#$NL,`$/Q``'-Z1`!W>D0`4_JBG(`&=[I
M.$5!\0`!S>D.`4_JF@!/ZIL!0.J+<-WI#F=`Z@(*0>H`"\WI$*L`)]WI#"-/
MZM9JW>D0`4KJ1QI00%E`!Z/3Z0`C$AEK0=WI$D5$0`G@K_,`@)EY@EH`````
MH>O9;@````!-0,WI%$5T`0J=1.H*!-WX4,!2&4/Q``,2ZPP`0_$``<WI"@'=
MZ0H!3^J(<@`9WNDZ14'Q``'-Z1(!3^J8`$_JF0%`ZHEPW>D2JT#J`@A!Z@`)
MS>D*B4_P``O=Z1`C3^K::-WI"@%(ZDL84$!90`_VF'/3Z0`C$AEK0=WI#D5$
M0$U`S>D414_J2A0,G43J"`3=^%#`4AG=Z0J)0_$``Q+K#`!#\0`!S>D,`=WI
M#`&R!P`90?$``<WI#@&P"+D(0.J'<-WI#D5`Z@(&0>H`!P_V.'/3Z0`C`"7>
MZ3P!S>D,9X;J"`:`&(?J"0=90=WI$B-/ZM1H<D![0,WI%"-(ZD48$)MB`=WX
M4,!"Z@@"P!C>Z3Z)0?$``1#K#`9!\0`'S>D09]WI$`%/ZIH&1NJ+=D_JFP>`
M&$?J!@M!\0`!S>D2`4_JBG#-Z1B)1NH`"LWI$*O=Z0P!#?6\?MWI$(G=Z1AG
MB.H`"(GJ`0D/]IQAT>D``=WI$B,`(S883T'=Z0X!3^K2:H#J"`"!Z@D!S>D4
M`4KJ0QH*F5`!W?A0P$#J"@!V&-[I`*M'\0`'%NL,"$?Q``G-Z0J)W>D*9T_J
MA'@-]<!^-AA'\0`'S>D.9Z8(KPA&ZH5VW>D.`4;J"`1'Z@8%S>D*10`AW>D0
M9\0.W>D*B43J012(Z@8(B>H'"0_V#&?7Z0!G%NL*!D?K"P?=Z1*KBNH("HOJ
M"0O-Z1BK3^I`&-WX,+!(Z@0(W?A@P!;K"P9'\0`'%NL,"D?Q``N6"!KK"`1&
MZH-V2_$`!9\(S>D2190'1NH$"D?J!@O-Z0RKW>D*1=WI#&?>Z0`C#?7$?F9`
M;T`/]I15U>D`1=WI$HE/\``)I!A=0=WI#B-/ZMAJ<D![0,WI%"-*ZDD:$)M/
MZD@2W?A0P$+J"@+D&-[I`*M%\0`%%.L,!D7Q``?-Z1!GW>D0188'#?7(?J08
M1?$`!<WI#D6$"(T(1.J!=-WI#B-$Z@8`1>H$`<WI$`$`(]WI#$70#MWI$&=`
MZD,09D!O0`_V"%75Z0!%%.L*!$7K"P7=Z1*KBNH&"HOJ!PO-Z1BK5@'=^"BP
M!D/=^&#`%.L+!$7Q``44ZPP*1?$`"T_JF`0:ZP8`1.J)=$OQ``%/ZID%S>D2
M`4_JB'#>Z0")1.H`"D7J!`O-Z0JKW>D0`0WUS'[-Z1B)W>D*B=WI&$6(Z@`(
MB>H!"0_VA$'1Z0`!W>D29P`G)!A-0=WI#@%/ZM9J@.H(`('J"0'-Z10!2NI'
M&@R9<`'=^%#`0.H*`&08WND`JT7Q``44ZPP(1?$`"<WI#(G=Z0Q%3^J">`WU
MT'XD&$7Q``7-Z0Y%E`B="$3J@W3=Z0X!1.H(`D7J!`/-Z0PC`"'=Z0I%P@[=
MZ0R)0NI!$HCJ!`B)Z@4)#_;T-=7I`$44ZPH$1>L+!=WI$JN*Z@@*B^H)"\WI
M&*M/ZD`8W?A`L$CJ`@C=^&#`%.L+!$7Q``44ZPP*1?$`"[0(&NL(`D3JAW1+
M\0`#O0C-Z1@CL@?>Z0!G1.H""D7J!`O-Z1"KW>D,(PWUU'[-Z1)GW>D09]WI
M$D560%]`#_9T,]/I`"/=Z1B)3_``":0874'=Z0XC3^K8:G)`>T#-Z1(C2NI)
M&@J;3^I($MWX2,!"Z@H"Y!C>Z0"K1?$`!13K#`9%\0`'S>D*9]WI"D6&!PWU
MV'ZD&$7Q``7-Z1Q%A`B-"$3J@73=Z1PC1.H&`$7J!`'-Z1(!`"/=Z1!%T`[=
MZ1)G0.I#$&9`;T`/]N@EU>D`113K"@1%ZPL%W>D8JXKJ!@J+Z@<+S>D*JU8!
MW?@PL`9#W?@HP!3K"P1%\0`%%.L,"D7Q``L:ZP8`2_$``4_JF`3-Z0P!1.J)
M=-WI#&=/ZID%3^J(<$_P``I/\``+S>D*JT3J``I%Z@0+S>D.JT_JUFO=Z1)%
M`"?=Z0X!3^K7;,WX*+!I0`J=8$#>Z0")1>I'%0J5W>D<10WUW'X/]D@KV^D`
MJT1`34#-Z1A%&NL("A"=2^L)"QB<3^I&&!KK!0K-^"S`2_$`"QKK!`!+\0`!
MW>D*J\WI$`&4"$CJ"@C=Z1"K1.J#=)`'&NL("D_JDP5$Z@`(W>D.`5)&2_$`
M"T7J!`G-Z1BKW>D,10`CWND`JPWUX'[-Z0J)2.H`"$GJ`0D$Z@@$W>D*`07J
M"07=Z0Z)S>D0JT_JTFK-Z0Q%`.H(`-WI$$5*ZD,:#_:D&=GI`(G=^$C`%.L(
M!$7K"07=Z0R)0.H(`!3K#`A%\0`)S>D,B=WI#$5/ZD(82.H*""083^J&<$7Q
M``7-Z0Q%W>D,J[0(1.J'=+T(&NL("D7J!`E$Z@`(W>D*159&S>D,B4OQ``O-
MZ1*K3_``"D_P``O-Z1"K2.H$"MWI&(GU#A"5`"?=Z0Q%"NH("MWI"HG>Z0`!
M3^K7;@3J"`0/]@09V>D`B=WX.,!*Z@0*$.L(`,WX1.!!ZPD!W?A`D!#K#`!/
MZD882>I'&<WX0)!!\0`!$.L*!-WI$*M!\0`%S>D.190(2.H*"-WI#JM$ZH-T
M#?7D?AKK"`I/ZH)P1.H`"$_JDP7=Z0P!4D9+\0`+1>H$"<WI&*L`(][I`*L-
M]>A^W>D21<WI$(E(Z@`(2>H!"03J"`3=Z1`!!>H)!=WI#(G-Z0ZK3^K2:LWI
M$D4`Z@@`W>D.14KJ0QH/]DP)V>D`B=WX*,`4ZP@$1>L)!=WI$HE`Z@@`%.L,
M"$7Q``G-Z0Z)W>D.14_J0AA(Z@H()!A/ZH9P1?$`!<WI"D7=Z0JKM`A$ZH=T
MO0@:ZP@*1>H$"43J``A+\0`+S>D2JU9&W>D014_P``K-Z0J)3_``"\WI#JM(
MZ@0*W>D8B?4.#I4`)]WI"D4*Z@@*W>D0B=[I``%/ZM=N!.H(!`_RK'G9Z0")
MW?@PP$KJ!`H0ZP@`S?@\X$'K"0'=^#B0$.L,`$_J1AA)ZD<9S?@XD$'Q``$0
MZPH$W>D.JT'Q``7-Z0Q%E`A(Z@H(W>D,JT3J@W0-]>Q^&NL("D_J@G!$Z@`(
M3^J3!=WI"@%21DOQ``M%Z@0)S>D8JP`CW>D21=[I`*L-]?!^S>D,B4CJ``A)
MZ@$)!.H(!-WI#`$%Z@D%W>D*B<WI#JM/ZM)JS>D210#J"`#=Z0Y%2NI#&@_R
M]&G9Z0")W?A`P!3K"`1%ZPD%W>D2B4#J"``4ZPP(1?$`"<WI#HG=Z0Y%3^I"
M&$CJ"@@D&$_JAG!%\0`%S>D01=WI$*NT"$3JAW2]"!KK"`I%Z@0)1.H`"$OQ
M``M61LWI$JO>Z0`!3_``"LWI$(E/\``+S>D.JP`GW>D,1?4.#I5/ZM=N2.H$
M"MWI&(G=Z1!%"NH("MWI#(G=^"C`!.H(!`_R4&G9Z0")S?@\X$KJ!`H0ZP@`
M3^I&&$'K"0'=^#B0$.L,``WU]'Y)ZD<9S?@XD$'Q``$0ZPH$W>D.JT'Q``7-
MZ0I%E`A(Z@H(W>D*JT3J@W20!QKK"`I/ZI,%1.H`"-WI$`%21DOQ``M%Z@0)
MS>D8J]WI$D4`(][I`*L-]?A^S>D*B4CJ``A)Z@$)!.H(!-WI"@$%Z@D%W>D0
MB<WI#JM/ZM)JS>D210#J"`#=Z0Y%2NI#&@_RG%G9Z0")W?@PP!3K"`1%ZPD%
MW>D2B4#J"``4ZPP(1?$`"<WI#HG=Z0Y%3^I"&$CJ"@@D&$_JAG!%\0`%S>D,
M1=WI#*NT"$3JAW2]"!KK"`I%Z@0)1.H`"-WI"D561M[I``%+\0`+S>D,B<WI
M$JOU#D_P``I/\``+S>D.JTCJ!`H.E0`GW>D8B4_JUV[=Z0Q%"NH("MWI"HG=
M^$#`!.H(!`_R_$G9Z0")S?@\X$KJ!`H0ZP@`3^I&&$'K"0'=^#B0$.L,``WU
M_'Y)ZD<9S?@XD$'Q``$0ZPH$W>D.JT'Q``7-Z1!%E`A(Z@H(W>D0JT3J@W20
M!QKK"`I/ZI,%1.H`"-WI#`%21DOQ``M%Z@0)S>D.J]WI$D4`(][I`*O-Z1")
M2.H`"$GJ`0D$Z@@$W>D0`07J"07=Z0R)S>D4JT_JTFK-Z1)%`.H(`-WI%$5*
MZD,:#_),2=GI`(G=^"C`%.L(!$7K"07=Z1*)0.H(`!3K#`A%\0`)S>D2B=WI
M$D5/ZD(82.H*"-WX,,`D&$_JAG!%\0`%S>D*1=WI"JNT"$3JAW2]"!KK"`I%
MZ@0)2_$`"\WI$JM61MWI$*M$Z@`(W>D.`<WI"HE(Z@H(2>H+"=WI$$4`Z@@`
M`>H)`0WU`'G-Z0X!W>D*`0`G3^K6:B!`V>D`10_RK#G9Z0")2NI'&A3K"`1%
MZPD%W>D.B4#J"``4ZPP(1?$`"<WI#HG=Z0Y%3^I&&$CJ"@C=^$#`)!A/ZH)P
M1?$`!<WI#$7=Z0RKE`A$ZH-TG0@:ZP@*1>H$"4OQ``O-Z0ZK4D;=Z0JK1.H`
M"-WI$@'-Z0R)2.H*"$GJ"PG=Z0I%`.H(``'J"0$-]0)YS>D2`=WI#`$`(T_J
MTFH@0-GI`$4/\@PYV>D`B4KJ0QH4ZP@$1>L)!=WI$HE`Z@@`%.L,"$7Q``G-
MZ1*)W>D214_J0AA(Z@H(W?@HP"083^J&<$7Q``7-Z1!%W>D0J[0(1.J'=+T(
M&NL("D7J!`E+\0`+S>D2JU9&W>D,JT3J``C=Z0X!S>D0B4CJ"@A)Z@L)W>D,
M10#J"``!Z@D!#?4$><WI#@'=Z1`!`"=/ZM9J($#9Z0!%#_)L*=GI`(E*ZD<:
M%.L(!$7K"07=Z0Z)0.H(`!3K#`A%\0`)S>D.B=WI#D5/ZD882.H*""083^J"
M<$7Q``7-Z0I%W>D*JY0(1.J#=)T(&NL("D7J!`E+\0`+S>D.JU)&W>D0JT3J
M``C=Z1(!S>D*B4CJ"@A)Z@L)`.H(``'J"0$-]09YS>D2`0`CW>D014_JTFK=
MZ0H!2NI#&MWX,,`@0-GI`$4/\L@9V>D`B13K"`1%ZPD%W>D2B4#J"``4ZPP(
M1?$`"<WI$HG=Z1)%3^I"&$CJ"@C=^$#`)!A/ZH9P1?$`!<WI#$7=Z0RKM`A$
MZH=TO0@:ZP@*1>H$"4OQ``O-Z1*K5D;=Z0JK1.H`"-WI#@'-Z0R)2.H*"$GJ
M"PG=Z0I%`.H(``'J"0$-]0AYS>D.`=WI#`$`)T_JUFH@0-GI`$4/\BP9V>D`
MB4KJ1QH4ZP@$1>L)!=WI#HE`Z@@`%.L,"$7Q``G-Z0Z)W>D.14_J1AA(Z@H(
MW?@HP"083^J"<$7Q``7-Z1!%W>D0JY0(1.J#=)T(&NL("D7J!`E+\0`+S>D.
MJU)&W>D,JT3J``C=Z1(!S>D0B4CJ"@A)Z@L)W>D,10#J"``!Z@D!#?4*><WI
M$@'=Z1`!`"-/ZM)J($#9Z0!%#_*,"=GI`(E*ZD,:%.L(!$7K"07=Z1*)0.H(
M`!3K#`A%\0`)S>D2B=WI$D5/ZD(82.H*"-WX,,`D&$_JAG!%\0`%S>D*1=WI
M"JNT"$3JAW2]"!KK"`I%Z@0)2_$`"\WI$JM61MWI$*M$Z@`(W>D.`<WI"HE(
MZ@H(2>H+"=WI$$4)X*_S`("AZ]EN`````-R\&X\``````.H(``'J"0$-]0QY
MS>D.`=WI"@$`)T_JUFH@0-GI`$4/]J1)V>D`B4KJ1QH4ZP@$1>L)!=WI#HE`
MZ@@`%.L,"$7Q``G-Z0Z)W>D.14_J1AA(Z@H(W?A`P"083^J"<$7Q``7-Z0Q%
MW>D,JY0(1.J#=)T(&NL("D7J!`E+\0`+S>D.JU)&W>D*JT3J``C=Z1(!S>D,
MB4CJ"@A)Z@L)W>D*10#J"``!Z@D!#?4.><WI$@'=Z0P!`"-/ZM)J($#9Z0!%
M#_8$2=GI`(E*ZD,:%.L(!$7K"07=Z1*)0.H(`!3K#`A%\0`)S>D2B=WI$D5/
MZD(82.H*""083^J&<$7Q``7-Z1!%W>D0J[0(1.J'=+T(&NL("D7J!`E+\0`+
MS>D2JU9&W>D,JT3J``C=Z0X!2.H*!$GJ"P7-Z1")($`I0,WI#@'=Z0Q%D*U`
M1MWX*,#5Z0")($`/]G0UU>D`10`G3^K6:ACK!`A*ZD<:2>L%"=WI#D4$0QCK
M#`!)\0`!S>D.`=WI#HEP`4#J"@#=^##`&.L$"$_J@G1)\0`)S>D*B4_JD@A/
MZI,)2.J#>-WI"JM(Z@0"2>H(`]WI$(D:ZP`*S>D*(TOQ``M"Z@@$0^H)!=WI
M$B-01LWI#JL`(2)`*T"2K<WI$B/=Z0HC3^K0:DKJ01H"Z@@"U>D`B0_VT"75
MZ0!%&.L$"$GK!0G=Z1)%%$,8ZPP"2?$``\WI$B/=Z1*)0@%"Z@H"W?A`P!CK
M!`A/ZH9T2?$`"<WI#(G=Z0RK3^J6"$CJAWA/ZI<)&NL""DCJ!`9)Z@@'S>D,
M9U)&W>D*B4OQ``O-Z1*KW>D,JP`CW>D.1=8.2NH("DOJ"0L$Z@H$W>D,B07J
M"P7=Z0JK#?44>\WI%$4(Z@H(#_8P)=7I`$7;Z0"K1NI#%D_JD0D4ZPH$1>L+
M!=WI%*O-Z0Y%5`%(Z@H(W>D.JS1#&NL,"@WU%GQ+\0`+&NL("DOQ``M/ZI`(
M&NL$!DCJ@7A+\0`'S>D.9X8'2>H(`4CJ!@#-Z1`!W>D09Y\(W>D,B=SI`*N&
MZ@@&#_;`&=GI`(G=Z0Y%`"4:ZP@*W?@HP$OK"0O=Z1*)X`X:ZPP*0.I%$(;J
M"`9/ZD082_$`"TCJ``@:ZP8*2_$`"QKK"`!+\0`!E@C-Z1(!D`>8JD;J@W9'
MZ@8#W>D2B=+I`*M&Z@`"S>D*(T_P``G=Z1!G3^K88MWI"@%"ZDD2W?@PP'!`
M#_8\%]?I`&<:ZP8*2^L'"]WI#F<:ZPP*W?A`P(#J!@!/ZD@61NH"!DOQ``L:
MZP`*3^J$<DOQ``L:ZP8`2_$``<WI#@&@")JL0.J%<*D(U.D`JT'J``5`Z@($
MS>D,1=WI#`'=Z0HCW>D.9P`G4$`/]M`#T^D`(QKK`@I/ZM9D2^L#"]WI$B,:
MZPP*1.I'%(#J`@!/ZD821.H"!$OQ``L:ZP`*3^J(<DOQ``L:ZP0`2_$``<WI
M$@%/ZI@`#?4<>$#JB7!/ZID!V.D`JT'J``E`Z@((S>D0B=WI$`'=Z0PCW>D2
M10`E4$`/]E@#T^D`(]WX*,`:ZP(*3^K4:$OK`PO=Z0XC&NL,"DCJ11B`Z@(`
M3^I$$DCJ`@A+\0`+&NL`"D_JAG)+\0`+&NL(`$OQ``'-Z0X!L`B>KD#JAW"Y
M"-WI#HE!Z@`'UND`JT#J`@;-Z0IG3_``"=WI"@%/ZMAFW>D0(T;J21;=^##`
M4$`/\M1ST^D`(QKK`@I+ZP,+W>D2(QKK#`K=^$#`@.H"`$_J2!)&Z@(&2_$`
M"QKK``I/ZH1R2_$`"QKK!@!+\0`!S>D2`:`(H*Q`ZH5PJ0C4Z0"K0>H`!4#J
M`@3-Z0Q%W>D,`=WI"B/=Z1)G`"=00`_R9'/3Z0`C&NL""D_JUF1+ZP,+W>D.
M(QKK#`I$ZD<4@.H"`$_J1A)$Z@($2_$`"QKK``I/ZHAR2_$`"QKK!`!+\0`!
MS>D.`4_JF``-]2)X0.J)<$_JF0'8Z0"K0>H`"4#J`@C-Z1")W>D,(]WI$`'=
MZ0Y%`"500`_R[&/3Z0`CW?@HP!KK`@I/ZM1H2^L#"]WI$B,:ZPP*2.I%&(#J
M`@!/ZD022.H""$OQ``L:ZP`*3^J&<DOQ``L:ZP@`2_$``<WI$@&P"*2N0.J'
M<+D(UND`JT'J``=`Z@(&S>D*9]WI"@'=Z1`CW>D2B4_P``E00`_R=&/3Z0`C
MW?@PP!KK`@I/ZMAF2^L#"]WI#B,:ZPP*1NI)%H#J`@!/ZD@21NH"!DOQ``L:
MZP`*3^J$<DOQ``L:ZP8`2_$``<WI#@&@"*:L0.J%<*D(U.D`JT'J``5`Z@($
MS>D,1=WI#`'=Z0HCW>D.9P`G4$`/\@!CT^D`(]WX0,`:ZP(*3^K69$OK`PO=
MZ1(C&NL,"D3J1Q2`Z@(`3^I&$D3J`@1+\0`+&NL`"D_JB')+\0`+&NL$`$OQ
M``'-Z1(!3^J8``WU*'A`ZHEP3^J9`=CI`*M!Z@`)0.H"",WI$(G=Z1`!W>D,
M(]WI$D4`)5!`#_*$4]/I`"/=^"C`&NL""D_JU&A+ZP,+W>D.(QKK#`I(ZD48
M@.H"`$_J1!)(Z@((2_$`"QKK``I/ZH9R2_$`"QKK"`!+\0`!S>D.`;`(JJY`
MZH=PN0C6Z0"K0>H`!T#J`@;-Z0IGW>D0(]WI"@'=Z0Z)3_``"5!`#_(,4]/I
M`"/=^##`&NL""D_JV&9+ZP,+W>D2(QKK#`I&ZDD6@.H"`$_J2!)&Z@(&2_$`
M"QKK``I/ZH1R2_$`"QKK!@!+\0`!S>D2`:`(K*Q`ZH5PJ0C4Z0"K0>H`!4#J
M`@3-Z0Q%W>D,`=WI"B/=Z1)G`"=00`_RE$/3Z0`CW?A`P!KK`@I/ZM9D2^L#
M"]WI#B,:ZPP*1.I'%(#J`@!/ZD821.H"!$OQ``L:ZP`*3^J(<DOQ``L:ZP0`
M2_$``<WI#@%/ZI@`#?4N>$#JB7!/ZID!V.D`JT'J``E`Z@((S>D0B=WI$`'=
MZ0PCW>D.10`E4$`/\AA#T^D`(]WX*,`:ZP(*3^K4:$OK`PO=Z1(C&NL,"DCJ
M11B`Z@(`3^I$$DCJ`@A+\0`+&NL`"D_JAG)+\0`+&NL(`$OQ``'-Z1(!L`BP
MKD#JAW"Y"-WI$HE!Z@`'UND`JT#J`@;-Z0IG3_``"=WI"@%/ZMAFW>D0(T;J
M21;=^##`4$#EH]/I`",:ZP(*2^L#"]WI#B,:ZPP*W?A`P(#J`@!/ZD@21NH"
M!DOQ``L:ZP`*3^J$<DOQ``L:ZP8`2_$``<WI#@&@"+*L0.J%<*D(U.D`JT'J
M``5`Z@($S>D,1=WI#`'=Z0HCW>D.9P`G4$#*H]/I`",:ZP(*3^K69$OK`PO=
MZ1(C&NL,"D3J1Q2`Z@(`3^I&$D3J`@1+\0`+&NL`"D_JB')+\0`+&NL$`$OQ
M``'-Z1(!3^J8``WU-'A`ZHEP3^J9`=CI`*M!Z@`)0.H"",WI$(G=Z0PCW>D0
M`=WI$D4`)5!`K:/3Z0`CW?@HP!KK`@I/ZM1H2^L#"]WI#B,:ZPP*2.I%&(#J
M`@!/ZD022.H""$OQ``L:ZP`*3^J&<DOQ``L:ZP@`2_$``<WI#@&P"+:N0.J'
M<+D(UND`JT'J``=`Z@(&S>D*9]WI"@'=Z1`CW>D.B4_P``E00(^CT^D`(]WX
M,,`:ZP(*3^K89DOK`PO=Z1(C&NL,"D;J21:`Z@(`3^I($D;J`@9+\0`+&NL`
M"D_JA')+\0`+&NL&`$OQ``'-Z1(!H`BXK$#JA7"I"-3I`*M!Z@`%0.H"!,WI
M#$7=Z0P!W>D*(]WI$F<`)U!`<J/3Z0`CW?A`P!KK`@I/ZM9D2^L#"]WI#B,:
MZPP*1.I'%(#J`@!/ZD821.H"!$OQ``L:ZP`*3^J(<DOQ``L:ZP0`2_$``<WI
M#@%/ZI@`#?4Z>$#JB7!/ZID!V.D`JT'J``E`Z@((S>D0B=WI#`%/ZI<)W>D0
M(]WI#D4`)4)`4Z'1Z0`!W?@HP``A$.L*`-WI$JM/ZM1H$.L,`$CJ11B"Z@H"
M3^I$&H`82NH("D_JE@A(ZH=X`">R!SM&`";-Z19GO*\0ZPH`2.H""C)&S>D*
M(TGJ"`O7Z0`C3^J4"3NGU^D`9]WX,,"2&<WI$JM[01+K#`9#\0`'W>D2(\WI
M%&=/ZM!KW>D09T_J0!K-^%BPW?A8@')`>T#=Z0YGS?@HD$CJ01A[0,WX6(#/
M#A>7W?@HP')`W>D69T_JA'C-Z0PC3.J%?-WI%"-&Z@H&S?@HP$_JE0K=^##@
MS?@LH-WI"JL2ZPX"DAG=^$#`W>D&9TKJ"`K=Z0")`"?=Z0)%3_``"1CK#`C=
M^$C@-AC=Z0@!%.L.!``E@!C=Z00C`"$`(Q+K"@+=^&R@RND``<KI`F?*Z09%
MRND(B<KI!",-]3]]O>CPCZ_S`(#<O!N/`````-;!8LH`````+>GX0P=&`"@Z
MT$SR.!/`\@$#T_@`@+CQ``\NT`9XB48]+AB_`"X4OP$F`"83T=CX`$!LL45&
M($8Y1C)&_/?>[Q"YHUT]*P_05?@$3P`L\M$@1KWH^(,&1A;X`3\]*QB_`"OY
MT?8;XN?(ZP4%<!P@1*T0R?@`4+WH^(-`1KWH^(.]Z/B#<+5,\C@5@K#`\@$%
M!D8P1@&I__>S_YBQ`9PI:`'KA`-::$'X)"``*O'0FFA#^`0O`"KZT3!&`:G_
M]Z#_`"CKT0*P<+TMZ?!/#$8+>(.P!D8]*PB_`30@1OSWX.X!J0=&,$;_]XO_
M!48`*%?0_/?6[H="1MD!FTSR.!C`\@$(3^J#"3%X/2D8OP`I%+\!(0`A!]`Q
M1A'X`3\]*QB_`"OYT8D;N!S8^`"`"$1,\C@5_/>2[L#R`05(^`D``"AHT"AH
M<1P!FC-X4/@B``-P8[$]*PK00AP!X#TK!M`1^`$[$$8"^`$[`"OVT0)&/2,#
M<!3X`3L"^`$_`"OYT0`@`["]Z/"/%/@!.P7X`3L`*_70%/@!.P7X`3L`*_/1
M[N=,\C@8P/(!"-CX`*#:^``P:[-31E/X!"\!-0`J^M&I'(D`3/)8$\#R`0,:
M:'*Q4$;\]_KMR/@``."Q3^J%"0-&:AP`(4/X(A`!E8SG"$8!(AI@_/<R[H-&
M8+%/ZH4)449*1OSWDNU;1LCX`+#HYQU&""'6YT_P_S"RYP"_`"A9T/"U!$8#
M>)VP"[D=L/"]_/<([@5&`"CXT"A&_/?`[@-&`/$3!B!&H[/:?"XJ.=#\]RCN
M!T8P1OSW).XX1`(P_/?\[0$A3_#_,@"43?:(8P&6P/(``P=&_/<R[CE&`R`"
MJOSWMNX!,#A&!=`&FP/T<$.S]8!/']#\]Y+M.$;\]TKM*$;\]XSN`T8`\1,&
M($8`*\K1*$;\][KN($;\]UKM';#PO1I]`"JWT"XJP-%;?0`KLM"\YW!'__>A
M_][G<+5,\D@4P/(!!"!H_/>F[H-O(&A=:/SWHNZ0^&5@(&C\]YSN!O!_!D-H
M&XK#\P@#1NK#%FZ`(&C\]Y#N@V\@:%UH_/>,[@`B3O*D$<#R``'\]\KMZ&$@
M:/SW@.Z#;R!H76C\]WSNT/@<-2!H*V+\]W;N@V\@:%UH_/=P[M#X-#$KL2!H
M_/=J[M#X-#$;;VMB`"4@:/SW8NZ#;R!H6VB=8OSW7.Z#;R!H6VB=8?SW5NZ#
M;R!H7&C\]U+NT/A0,N-B<+T`OSBU3/)(%,#R`00%1B!H_/=$[BE&`/6@<@,@
M_/<R[@BQ`"`XO2!H_/<X[M#X4#$#]'!#L_6`3PG0(&C\]R[NT/A0,0/T<$.S
M]2!/Z=$H1@(A_/?&[;#Z@/!`"3B]\+5,\D`4K?6`7<#R`02#L`9&(V@-]8!5
M!#4/1DWVD&`!J<#R``!`]O]R*V#\]^#L`"@CW44>`:M:7>JQ!48!J"\A*D;\
M]YCMP+%,\D@3P/(!`QAH_/?R[3%&`:HK1OSWMNT-]8!5!#4J:"-HFD(1T0WU
M@%T#L/"]`"W@T4SR2!/`\@$#&&C\]]KM,48Z1OSWJNSFY_SWANQ,\D@3P/(!
M`Q"U&&C\]\KM3?:@84GR]%)-]KQCP/(``<#R``+`\@`#O>@00/SW(+T0M4SR
M2!3`\@$$@K`@:/SWLNW_]]W_(&C\]ZSM`").\J03`9+`\@`#3?;(80"3P/(`
M`4WV:2+`\@`"_/<T[0*P$+T`OW"U3/)`%*WU`%W`\@$$AK`C:`WU`%(4,A-@
M_/>R[$WV[&)-]N!CP/(``L#R``,!D@$A0?(!`@"0`ZC\]\SL`"@BVPWU@%$#
MJ$_T@%(0,?SW2NP%'AC;:!S\]WKL!D9`L0WU@%$J1A`Q_/?LZS!&`"-S50WU
M`%,4,QIH(VB:0@71#?4`70:P<+T`(/+G_/<$[/_WMK\MZ?!/3/)`%ZWU@5W`
M\@$'@;`%1CMH#?6`4APR#D9-]O1@!JG`\@``$V#_]QO]+R$$1BA&_/=R[*"Q
M3?8`<"E&P/(``/_W<OTH1@WU@%,<,QIH.VB:0D#PD8`-]8%=`;"]Z/"/*$;\
M]T[L3?80<<#R``&#1C!&_/?"[()&`"C<T$WV\&E,\D@8!Z[`\@`)P/(!"$WV
M''+`\@`"!9*:^``P`"L(O\I&++$@1E%&_/=6ZP`H1]!01OSW)NP*ZP`#`D83
M^`$<+RD'T0`@`_@!#0$Z$_@!'"\I^-`!,EI$LO6`7ZO:!9H!(<WX`*!-]A1S
M`I7`\@`#`9(P1D_T@%+\]R#LV/@``/SWRNPQ1@#UH'(#(/SWH.Q0N=CX``#\
M]\#LT/A0,0/T<$.S]0!/%M!-]A!Q`"#`\@`!_/=B[()&NO$`#ZS1>N=-]A!Q
MP/(``?SW5NR"1KKQ``^AT6_G,$8!(?SW0NP`*.+1,49-]@!PP/(``/_WW/PP
M1OSW\NMFY_SW0NL#>#NQ0APO*PB_$$82^`$[`"OXT7!'`+\0M:"S`W@$1HNS
M_/>PZP$X(QB<0@S2(EPO*C+16AX"X!EX+RDMT:)"$T8"\?\R]]&C0AB_`_'_
M,P/1%>`1>"\I!-&<0AI&`_'_,_?3$AN3'+/U@%\3V"%&`3)/](!3$DC\]_[J
M$$@0O1MX+RL4T0(@_/=8ZP-&$+$N(AJ`$+T`(!"]6AX"X!EX+RG1T)1"$T8"
M\?\R]]/+YTWV''#`\@``O>@00/SWC+M<P0$`\+5-]AADP/(`!(VP`JU,\D`6
M#\S`\@$&-V@/Q0_,"Y<D:`_%3?8@<,#R```L@/_W.?Q-]BQPP/(``/_W,_Q-
M]C1PP/(``/_W+?Q-]D!PP/(``/_W)_Q-]DAPP/(``/_W(?Q-]EAPP/(``/_W
M&_Q-]O1@P/(``/_W%?Q-]F1PP/(``/_W#_Q-]G!PP/(``/_W"?Q-]GQPP/(`
M`/_W`_Q-]@!PP/(``/_W_?M-]HAPP/(``/_W]_M-]I1PP/(``/_W\?M-]J!P
M`:G`\@``__>H^S"Q`49-]G!PP/(``/_W!/Q-]K1P`:G`\@``__>9^S"Q`49-
M]LAPP/(``/_W]?M-]M1P`:G`\@``__>*^["Q`49-]O1@P/(``/_WYOM-]DAP
M3O($`<#R``#`\@`!__?<^PN:,VB:0B71#;#PO4WVY'`!J<#R``#_]VO[.+$!
M1DWV9'#`\@``__?'^]_G3?;X<0WQ&0#`\@`!"B+\]UCK`"C4T4WV9'`-\2,!
MP/(``/_WL_O+Y_SW'.H0M4SR,!3`\@$$@K`@:$,<`=`"L!"]3?9D<`&IP/(`
M`/_W.OL@L0!X$+$P.!B_`2`@8`*P$+T`OPBU_/>\Z?SWKND`L0!H"+TMZ?!#
M!T8E3(VP!:T/S`_%E.@'``6<A>@'`.RQ3?80>`6MP/(`"`7@_/>(Z;BQ5?@$
M3XRQ!*D@1O_W"OLY1@9&$+$#>``K[]$@1CE&__=D^U7X!$\`+.W1#;"]Z/"#
M.$;\]T;J@48P1OSW0NI(1`(P_/<:Z@"7S?@$@`$A`I9/\/\R3?84<\#R``.!
M1OSW3NH@1DE&__=`^\GG`+\\W@``B4LMZ?!/!4:3Z`<`K?4!39&P`_$,!A*O
M`_$D#!BL3/)`&8?H!P#`\@$)#\X-\50.V?@`@,WX+)`-]0%)"?$\"0_$EN@#
M`,GX`("$Z`,`G.@'`([H!P!-]O1@$:G`\@``__>F^B"Q`W@$1@`K0/"*@?_W
M;O\4K(!&`"A3T$!&_/?HZ4```3#\]\#IF/@`,`9&!$9[L0"3($9.\A`#`2'`
M\@`#3_#_,OSW\ND8^`$_`C0`*^_1&)@8K!BY%.!4^`0/B+$1J?_W=/J`1@`H
M]M`#>``K\]#_]SS\`"COT$!&_/?DZ8%&<+L2G%2S(WA/\`$(.[DEX%?X*$`4
MLR-X"/$!"/.Q($;_]R3\`"CST"!&_/?,Z0`H[M"!1A3@_/?&Z0`H0/`N@53X
M!`\`*`#P,8$1J?_W/OH`*/70`W@`*_+0[.=/\``)2$9-]AQX_/>"Z<#R``@$
M1C!&_/=\Z2!$`/($1"!&_/=2Z0$AS?@`D$[R)`(#EL#R``+-^`2`3O(8`P*2
MP/(``T_P_S*#1OSW@.E81D_TX''\]Y;I`3`NT$SR2!;`\@$&,&C\]R#J648`
M]:!R`R#\]P[J`"@XT$SR4!'`\@$!*VA.\JP""&C`\@`"S?@`L`$A_/>:Z0`@
M#?4!0]WX+)`\,QIHV?@`,)I"0/"T@@WU`4T1L+WH\(_\]T+I!F@1+LO03/)0
M$<#R`0$K:$[R+`((:,#R``+-^`"P`2$!EOSW=.D`(-CG6-X``#!H_/?<Z=#X
M4#$#]'!#L_6`3[S1,&C\]]+IT/A8<?SW0.B'0K/1,&C\]\CIT/A0,</S"`.S
M]>!_J=$@1OSWSN@1J8)&3O+X$,#R``#_]YKY`"@`\&V"+&C\]Q#I`48@1O_W
M7OP$1@`H`/!B@B!&_/?:Z`,H!D81W00X3O)H`2!$P/(``?OW^N]`N00N`/#G
M@29$%O@%/"\K`/#A@?_W)OX!1BBY($;\]Y3H#)``*%_13?9D<$[R!`'`\@``
MP/(``?_WQ/E.\J06_/>@Z,#R``;-^`"P3O*(`\WX!(#`\@`#`Y8!(4_P_S(`
M)5]&`I!01OSWMN@6X/SWKN@#:!$K&='\]X3H`35.\I@#`)<B1@.5S?@$@,#R
M``,$E@$A`I!01OSWGNA01D_TX''\][;H0QP$1N#0NT981OOWON]11DWV]&#`
M\@``__>!^5!&__?R_5!&+.>`1GOF__?L_2!&_/>.Z"3G3O(("`T@P/(`"'3F
M3_#_,V_P$0(")`"4_/<0Z$^I#)@&(OOWAN^=^#PQ([F=^#TQ0RL`\)*!`"0`
M(@"4`",,F`WQ\`G[]_KOX:'1Z0`!XJ/3Z0`CXJ?7Z0!G3)3-Z3`!X:75Z0!%
MXJ'1Z0`!S>DR(P`B`"/-Z31GS>DV1<WI."/-Z3HCS>DN`<WX-*#-^#BPS?@\
M@`R83ZE/]`!"^_=([[#Q``A[W4_JZ'7=Z3@C1$;=Z3JKZ0!!ZEAP3^K(`0>0
M!I'=Z09G`">V&)]""+^60@/2&O$!"DOQ``MB#VD/0NK%``F1")#=Z0@!3)L:
MZP`*S>DX9TOK`0O-Z3JK`"M,T,/Q0`8#\3@`1D4NJ0A$3ZFHOT9&,D;[]RKO
M3)LS1$R30"NWT4^J+JC&ZP@(%D3\]^_YN/$_#R?=J/%`"P;Q@`<&\4`,3^J;
M&@?KBA>L\4`$SD8@:!`T5/@,''5&5/@(+`[Q$`Y4^`0\9$4/Q?'1+JC\]\[Y
M!/%`#+Q%Y]$*\0$#J^N*&`;K@Q8Q1DA&0D9((_OW0N_-^#"!?.=/KLGG#)C=
M^#2@W?@XL-WX/(#\]T+H.)PNJ8`@.IW$\\4"4QP11#@K@?@X``+Q.0``\ZR`
M#?&X"<+Q-P)(1``A^_>R[RZH*@XK#(WX*U&-^"]!+0J-^"@A(Z^-^"DQ(PZ-
M^"I1+:Z-^"PQ(PPD"HWX+3&-^"Y!_/=^^=WXN,`>K=WXP.`RF#293^H<1#::
M3^H<8XWX>\!/ZAPLC?AY0#Q&C?AZP$_J'FR-^'_@C?A\P$_J'DR-^(,`3^H>
M+HWXAQ"-^'[@3^H0;HWXBR"-^(#@3^H03HWX>#``"HWX@>!/ZA%NC?B"``@,
MC?B$X`D*3^H2;HWXA0"-^'W`$`R-^(80$@J-^(C@C?B)`(WXBB`!X!7X`3\`
MDR!&3O(0`P(TP/(``P$A3_#_,OOW'.^T0N_1S?@`L``DS?@$@$[RI!("E\#R
M``).\G@#`Y+`\@`#4$8!(4_P_S*'^"A`^_<"[VOF;6@`+3_T&ZXH1OOWW.X#
M*'_V%:X$.$[R<`$H1,#R``'[]_[M`"@(ORQ&".8NJ\+Q/P(81``A^_<&[RZH
M_/?K^``C/),]DSZ3/Y-`DT&30I-#DT2319-&DT>32)-)DT'GG?@^,4$K?_1I
MKIWX/S%#*W_T9*Z=^$`Q2"M_]%^NG?A!,44K?_1:KD_P_S,`E`R8;_`Y`OOW
M5NY/J0R8*2+[]\KM3ZG-^`"P3O*D$@*1P/(``LWX!(!.\G@#`Y+`\@`#4$8!
M(4_P_S+[]YSN!.;[]_KM+&B;Y8FKS>\`````_MRZF`````!V5#(0`````/#A
MTL,``````2-%9P`````MZ?!/3/)(&,#R`0B#L-CX``#[]R;O`2,!J8#X83!-
M]DAPP/(``/[W__X8L0-X,2L`\.F`__?H^MCX``!-\E`G^_<.[T[R`!$!(L#R
M``$+(\#R`0?[]R#N`"A'T%?X]#P":0$KTO@8D$#=3/)(&@`FP/(!"@$D"N`!
M:5A&^_=0[5?X]#QXNP$T`3:C0BO=V/@``/OWYNY)1C)&`"/[]Y;N!48`*`#P
MJ(``:$_T@&/`\B`#5_CP'()H4?@DL!-`L_6`;]G0VO@``/OWRNX"(REH`"+[
M]ZSM`4981OOW(NU7^/0\`"C/T%H>LD)MT-CX``!,\D@4^_>T[D[R"!$!(L#R
M``$$(\#R`03[]\;M!49XL2!H^_>F[BMI3O(,$L#R``(9:/OW<NTK:1MHFVA;
M`EO4V/@``$SR2!3[]Y+N3O(4$0$BP/(``00CP/(!!/OWI.T%1I"Q3?8`<`&I
MP/(``/[W8_X&1B!H`"X`\(&`^_=X[BMI,D89:/OW2.W8^```3/)(&?OW;NX`
M(@&I3?)0),#R`0G`\@$$`T9-]O1@@_AA(,#R``#^]T#^!D9'^.P,>+-/].!Q
M^_?"[1$H`M!#'`$K?-@#L+WH\(\!*X_=`238^````33[]T3N24;[]\;L5_CT
M/*-"\]R!YR!H^_<Z[BMI&6C[][SMF^=7^/0\6AZR0G_T=*_@YT-X`"L_]!6O
M$>=4^/`,__<P^T3X[`P`*$?0*FE/](!CP/(@`Q)HD6@+0+/U@&\QT1!I5_CP
M3"%&^_>@["MI)FA/](!BP/(@`AQHHV@:0++U@&\'1A+1(FE.\CP0,48[1L#R
M``#[]U+M^_?X[2II5_CP/!!H&6C^]]+_>^?8^```^_?L[2EI`"("(PEH^_?,
M[`)&X>?9^```^_?@[2EI,D8"(PEH^_?`[,/G3O(8$,#R``#[]RKM5/CP'`-&
M,D9.\F00P/(```EH^_<@[0"_.+4%1O_W0/D#>`1&.[%"'"\K"+\41A+X`3L`
M*_C1__=-^EBQ5;$K>$.Q3O(D`2!&P/(``?OW!.R$0@#0.+TH1KWH.$#^]Y2^
M$+5,\D@4P/(!!"!H^_>:[4_P_S'[]X[L(&C[]Y3M3/9M,0`BP/(``;WH$$#[
M]UZ]K_,`@`)+>T0#L1MH^_<\O&[C```MZ?A#!T8,3HA&#$V11GY$^_?`ZWU$
M=ANV$`K0!#T`)`$T5?@$/SA&049*1IA'M$+VT;WH^(,`OQ[A```4X0``<$<`
MOPA`+>D(@+WH`0`"`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`````-CA``#HX0``\.$``/CA````X@``%.(```````#0X0``\-X```````#(
MWP``S-\``,3A``#XW@``S.$```````"PX0``N.$````````E<R\E<P```"]P
M<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R
M;'AS:2YC````26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`
M97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E
M<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%2
M7T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````4$%27T%21U9?,```
M4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]4
M35!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!
M4E]#3$5!3CT``#$```!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R
M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*``!P87)L`````"YP87(`````)7,E<V-A8VAE
M+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``$%21U8`````
M&````'!E<FP`````,````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T52
M3D%-10````!414U01$E2`%1-4``O=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,
M24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42````%-(
M3$E"7U!!5$@``",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM
M(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP
M:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@
M)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@
M=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T
M(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N
M="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4
M:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@
M=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R
M87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK
M('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O
M('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E
M<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E
M8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@
M8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G
M+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@
M("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE
M97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF
M:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@
M)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@
M("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@
M("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*
M("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D[
M"@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%2
M1U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]
M+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!
M4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@
M("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]
M"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N
M86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C
M:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T
M87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B
M=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@
M.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@
M('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E
M860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN
M=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q
M*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY
M("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@
M("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@
M("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO
M9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E
M;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%2
M7U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@
M("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@
M/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@
M("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@
M>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M
M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\
M?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A
M8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X
M="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y
M(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E
M("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@
M("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@
M("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D
M(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN
M="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L
M(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T
M96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@
M(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@
M("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F
M:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@
M("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN
M:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E
M(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W
M(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN
M"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H
M92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@
M("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@
M;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@
M)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O
M;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@
M>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A
M;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO
M=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T
M7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@
M("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@
M("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D[
M"@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP
M87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C
M('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E
M860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T
M('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@
M0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@
M("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@
M("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`
M861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R
M(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G
M*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@
M("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B
M=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A
M;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@
M("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M
M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'
M5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@
M("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E
M<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@
M("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D
M("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H
M+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U
M:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@
M>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@
M("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@
M("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A
M;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O
M<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@
M(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@
M("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I
M;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY
M("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@
M("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P
M*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@
M("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@
M("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@
M("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT
M*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7
M<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@
M("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@
M("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S
M;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@
M("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI
M<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U
M;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S
M<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@
M8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U
M92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P
M86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@
M("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@
M("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@
M9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG
M>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M
M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@
M)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@
M("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@
M("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE
M+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@
M("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@
M("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE
M(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@
M("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*
M("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@
M("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@
M(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC
M('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@
M(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD
M(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C
M86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C
M('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@
M:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F
M:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C
M($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,
M:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@
M(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@
M("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@
M("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@
M("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@
M("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]
M>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@
M("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M
M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D
M4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S
M=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@
M=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@
M("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D
M;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q
M=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@
M("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R
M97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I
M<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A
M<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N
M;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z
M.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A3
M3&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(
M86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q
M=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E
M(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@
M<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N
M(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4
M:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?
M<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N
M.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2![
M"B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@
M("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE
M<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@
M("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@
M("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*("`@("`@("!M:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@
M;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E
M96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@
M("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D
M8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@
M("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O
M<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!
M4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P
M-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`
M7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@
M(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE
M.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@
M(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@
M*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I
M;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R
M;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!
M4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N
M86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G
M;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@
M("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@
M("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@
M("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@
M("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@
M("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]
M"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@
M+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@
M("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!]
M(&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@
M("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@
M?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@
M*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U
M8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@
M("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA
M:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN
M.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*`-!<_W\!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!=FP``19L````````!`````0````$````-`@```0``
M`%P"```!````KP,```P```!<E0``#0````S>```9````]+X!`!L````$````
M&@```/B^`0`<````!````/7^_V^T@0``!0```'2,```&````=(4```H```!'
M!0``"P```!`````5``````````,`````P`$``@```#`"```4````$0```!<`
M```LDP``$0```/R2```2````,````!,````(````_O__;YR2``#___]O`P``
M`/#__V^\D0``````````````````````````````````````````````````
M`````````````````+\!````````````:)4``&B5``!HE0``:)4``&B5``!H
ME0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5
M``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4`
M`&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``
M:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!H
ME0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4``&B5
M``!HE0``:)4``&B5``!HE0``:)4``&B5``!HE0``:)4`````````````````
M`/____\@X@``1T-#.B`H56)U;G1U+TQI;F%R;R`T+C@N,BTQ-'5B=6YT=3$I
M(#0N."XR`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XX+C(M,3-U8G5N='4Q*2`T
M+C@N,B`R,#$T,#$Q,"`H<')E<F5L96%S92D@6VEB;2]G8V,M-%\X+6)R86YC
M:"!M97)G960@9G)O;2!G8V,M-%\X+6)R86YC:"P@<F5V:7-I;VX@,C`U.#0W
M70!!-````&%E86)I``$J````!3<M00`&"@=!"`$)`@H$$@03`10!%0$7`Q@!
M&0$:`AL#'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN
M;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````
M````````````````````````````````````````"P````$````"````5($`
M`%0!```9```````````````!`````````!,````'`````@```'"!``!P`0``
M(```````````````!``````````A````!P````(```"0@0``D`$``"0`````
M``````````0`````````-````/;__V\"````M($``+0!``#``P``!0``````
M```$````!````#X````+`````@```'2%``!T!0````<```8````!````!```
M`!````!&`````P````(```!TC```=`P``$<%``````````````$`````````
M3@```/___V\"````O)$``+P1``#@````!0`````````"`````@```%L```#^
M__]O`@```)R2``"<$@``8`````8````#````!`````````!J````"0````(`
M``#\D@``_!(``#`````%``````````0````(````<P````D````"````+),`
M`"P3```P`@``!0````P````$````"````'P````!````!@```%R5``!<%0``
M#```````````````!`````````!W`````0````8```!HE0``:!4``&P#````
M``````````0````$````@@````$````&````V)@``-@8```T10``````````
M```(`````````(@````!````!@````S>```,7@``"```````````````!```
M``````".`````0````(````4W@``%%X``+Q?``````````````0`````````
ME@````$``'""````T#T!`-"]```(````#0`````````$`````````*$````!
M`````@```-@]`0#8O0``!```````````````!`````````"K````#@````,`
M``#TO@$`]+X```0```````````````0`````````MP````\````#````^+X!
M`/B^```$```````````````$`````````,,````!`````P```/R^`0#\O@``
M!```````````````!`````````#(````!@````,`````OP$``+\````!```&
M``````````0````(````T0````$````#`````,`!``#````H`0``````````
M```$````!````-8````!`````P```"C!`0`HP0``$```````````````!```
M``````#<````"`````,````XP0$`.,$``#00``````````````@`````````
MX0````$````P`````````#C!``"M```````````````!`````0```.H````#
M``!P``````````#EP0``-0```````````````0`````````!`````P``````
M````````&L(``/H```````````````$``````````0```&B5```````````,
M``0```!XE0``````````#``!````?)4```````````P`!P```#R6````````
M```,``$```!`E@``````````#``'````A)<```````````P``0```(B7````
M```````,``<```"4EP``````````#``!````F)<```````````P`!P```'"8
D```````````,``$```!TF```````````#```)&$`)&0`)'0`
